@@ -128,7 +128,9 @@ class client:
                 board.generate_ports(port_list)
                 self.client_instance.enemy_list = enemy_list
                 self.client_instance.board_updated = True
+            elif Response.split('|')[0] == "startgui":
                 threading.Thread(target=self.board_thread, args=(board,)).start()
+                ClientSocket.send(str.encode("started\n"))
             elif Response == "getstart":
                 #print("get starting resources")
                 self.client_instance.start_resources()
@@ -296,13 +298,13 @@ def main():
     client(address, int(port), name, int(num_players))
 
 
-#if __name__ == "__main__":
+if __name__ == "__main__":
 #     host = '127.0.0.1'
 #     port = 1233
 #     xy = ''
 #     Name = "Name"
 #     players = 2
-#    test = client('127.0.0.1', 1233, 'zander', 2)
+    test = client('127.0.0.1', 1233, 'zander', 3)
 #     host = sys.argv[1]
 #     try:
 #         port = int(sys.argv[2])
