@@ -35,13 +35,13 @@ WINDOW_CENTER = (RESOLUTION[0] / 2, RESOLUTION[1] / 2)
 
 #for prototype
 FULLSCREEN = False
-RESOLUTION = (960, 540)
-PROTOTYPE_SCALE = 50/100
+RESOLUTION = (1600, 900)
+PROTOTYPE_SCALE = 83/100
 ACTION_SIZE = (int(70 * PROTOTYPE_SCALE), int(98 * PROTOTYPE_SCALE))
 HEX_SIZE = 600 * SCALE * PROTOTYPE_SCALE
 WINDOW_CENTER = (RESOLUTION[0] / 2, RESOLUTION[1] / 2)
 SPACING = 1
-CARD_SIZE = (35, 45)
+CARD_SIZE = (int(70 * PROTOTYPE_SCALE), int(98 * PROTOTYPE_SCALE))#(35, 45)
 
 COLORS = {
     'red': (127, 0, 0),
@@ -943,9 +943,9 @@ class Client:
 
         font_size = int(45 * PROTOTYPE_SCALE)
         self.font_bank = pygame.font.SysFont('Comic Sans MS', font_size)
-
+        print(self.player.screen_num)
         screenstring = "localhost:0."+self.player.screen_num
-        os.environ["DISPLAY"] = screenstring
+        os.putenv("DISPLAY", screenstring)
         os.environ['SDL_VIDEODRIVER'] = 'x11'
         if FULLSCREEN:
             self.game_window = pygame.display.set_mode(RESOLUTION, pygame.FULLSCREEN)
