@@ -3,7 +3,7 @@ import socket
 import time
 import sys
 
-from frontiersman.client import ClientHelper
+#from frontiersman.client import ClientHelper
 
 
 class client:
